package com.vctgo.system.service;

import java.util.List;

import com.vctgo.system.domain.SysTeachEducation;
import com.baomidou.mybatisplus.core.metadata.IPage;

/**
 * 幼儿园教职工与学历关联Service接口
 *
 * @author caesar
 * @date 2024-03-27
 */
public interface ISysTeachEducationService {
    /**
     * 查询幼儿园教职工与学历关联
     *
     * @param id 幼儿园教职工与学历关联主键
     * @return 幼儿园教职工与学历关联
     */
    SysTeachEducation selectSysTeachEducationById(Long id);

    /**
     * 查询幼儿园教职工与学历关联列表-分页
     *
     * @param sysTeachEducation 幼儿园教职工与学历关联
     * @return 幼儿园教职工与学历关联集合
     */
    IPage<SysTeachEducation> selectSysTeachEducationPage(SysTeachEducation sysTeachEducation);

    /**
     * 查询幼儿园教职工与学历关联列表
     *
     * @param sysTeachEducation 幼儿园教职工与学历关联
     * @return 幼儿园教职工与学历关联集合
     */
    List<SysTeachEducation> selectSysTeachEducationList(SysTeachEducation sysTeachEducation);

    /**
     * 新增幼儿园教职工与学历关联
     *
     * @param sysTeachEducation 幼儿园教职工与学历关联
     * @return 结果
     */
    int insertSysTeachEducation(SysTeachEducation sysTeachEducation);

    /**
     * 修改幼儿园教职工与学历关联
     *
     * @param sysTeachEducation 幼儿园教职工与学历关联
     * @return 结果
     */
    int updateSysTeachEducation(SysTeachEducation sysTeachEducation);

    /**
     * 逻辑删除幼儿园教职工与学历关联
     *
     * @param ids
     * @return 结果
     */
    int logicalDeleteSysTeachEducationByIds(Long[] ids);

    /**
     * 批量删除幼儿园教职工与学历关联
     *
     * @param ids 需要删除的幼儿园教职工与学历关联主键集合
     * @return 结果
     */
    int deleteSysTeachEducationByIds(Long[] ids);

    /**
     * 删除幼儿园教职工与学历关联信息
     *
     * @param id 幼儿园教职工与学历关联主键
     * @return 结果
     */
    int deleteSysTeachEducationById(Long id);
}
